"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const bull_1 = require("./bull");
const mockJobId = 'id';
const mockQueueName = 'q';
const none = 'none';
const mockJob = {
    id: mockJobId,
};
const mockQueue = {
    name: mockQueueName,
    getJob(id) {
        return __awaiter(this, void 0, void 0, function* () {
            if (id === mockJobId) {
                return mockJob;
            }
            return null;
        });
    },
    getCompletedCount: jest.fn().mockImplementation(() => Promise.resolve(1)),
    getFailedCount: jest.fn().mockImplementation(() => Promise.resolve(2)),
    getDelayedCount: jest.fn().mockImplementation(() => Promise.resolve(3)),
    getActiveCount: jest.fn().mockImplementation(() => Promise.resolve(4)),
    getWaitingCount: jest.fn().mockImplementation(() => Promise.resolve(5)),
    getPausedCount: jest.fn().mockImplementation(() => Promise.resolve(6)),
    count: jest.fn().mockImplementation(() => Promise.resolve(7)),
};
const createDataSrc = () => new bull_1.BullDataSource([mockQueue]);
describe('bull data source', () => {
    test('it should get queue by name', () => {
        expect(createDataSrc().getQueueByName(mockQueueName)).toBe(mockQueue);
        expect(createDataSrc().getQueueByName(none)).toBeUndefined;
        expect(() => createDataSrc().getQueueByName(none, true)).toThrow(bull_1.ErrorEnum.QUEUE_NOT_FOUND);
    });
    test('it should get job by id', () => __awaiter(void 0, void 0, void 0, function* () {
        yield expect(createDataSrc().getJob(mockQueueName, mockJobId)).resolves.toBe(mockJob);
        yield expect(createDataSrc().getJob(none, mockJobId)).rejects.toThrow(bull_1.ErrorEnum.QUEUE_NOT_FOUND);
        yield expect(createDataSrc().getJob(mockQueueName, none, true)).rejects.toThrow(bull_1.ErrorEnum.JOB_NOT_FOUND);
        yield expect(createDataSrc().getJob(mockQueueName, none)).resolves.toBe(null);
    }));
    test('it should return completed count', () => __awaiter(void 0, void 0, void 0, function* () {
        yield expect(createDataSrc().getQueueCompletedCount(mockQueueName)).resolves.toBe(1);
        expect(mockQueue.getCompletedCount).toBeCalled;
        mockQueue.getCompletedCount.mockClear();
        expect(createDataSrc().getQueueCompletedCount(none)).resolves.toBe(undefined);
        expect(mockQueue.getCompletedCount).not.toBeCalled;
    }));
    test('it should return failed count', () => __awaiter(void 0, void 0, void 0, function* () {
        yield expect(createDataSrc().getQueueFailedCount(mockQueueName)).resolves.toBe(2);
        expect(mockQueue.getFailedCount).toBeCalled();
        mockQueue.getFailedCount.mockClear();
        yield expect(createDataSrc().getQueueFailedCount(none)).resolves.toBe(undefined);
        expect(mockQueue.getFailedCount).not.toBeCalled;
    }));
    test('it should return delayed count', () => __awaiter(void 0, void 0, void 0, function* () {
        yield expect(createDataSrc().getQueueDelayedCount(mockQueueName)).resolves.toBe(3);
        expect(mockQueue.getDelayedCount).toBeCalled();
        mockQueue.getDelayedCount.mockClear();
        yield expect(createDataSrc().getQueueDelayedCount(none)).resolves.toBe(undefined);
        expect(mockQueue.getDelayedCount).not.toBeCalled;
    }));
    test('it should return active count', () => __awaiter(void 0, void 0, void 0, function* () {
        yield expect(createDataSrc().getQueueActiveCount(mockQueueName)).resolves.toBe(4);
        expect(mockQueue.getActiveCount).toBeCalled();
        mockQueue.getActiveCount.mockClear();
        yield expect(createDataSrc().getQueueActiveCount(none)).resolves.toBe(undefined);
        expect(mockQueue.getActiveCount).not.toBeCalled;
    }));
    test('it should return waiting count', () => __awaiter(void 0, void 0, void 0, function* () {
        yield expect(createDataSrc().getQueueWaitingCount(mockQueueName)).resolves.toBe(5);
        expect(mockQueue.getWaitingCount).toBeCalled();
        mockQueue.getWaitingCount.mockClear();
        yield expect(createDataSrc().getQueueWaitingCount(none)).resolves.toBe(undefined);
        expect(mockQueue.getWaitingCount).not.toBeCalled;
    }));
    test('it should return paused count', () => __awaiter(void 0, void 0, void 0, function* () {
        yield expect(createDataSrc().getQueuePausedCount(mockQueueName)).resolves.toBe(6);
        expect(mockQueue.getPausedCount).toBeCalled();
        mockQueue.getPausedCount.mockClear();
        yield expect(createDataSrc().getQueuePausedCount(none)).resolves.toBe(undefined);
        expect(mockQueue.getPausedCount).not.toBeCalled;
    }));
    test('it should return waiting or delayed count', () => __awaiter(void 0, void 0, void 0, function* () {
        yield expect(createDataSrc().getQueueWaitingOrDelayedJobsCount(mockQueueName)).resolves.toBe(7);
        expect(mockQueue.count).toBeCalled();
        mockQueue.count.mockClear();
        yield expect(createDataSrc().getQueueWaitingOrDelayedJobsCount(none)).resolves.toBe(undefined);
        expect(mockQueue.count).not.toBeCalled;
    }));
});
//# sourceMappingURL=bull.spec.js.map